package fortyonepost.com.lsth; // 41 Post - Created by DimasTheDriver on Jan/14/2012 . Part of the 'Android: how to create a loading screen  Part 2' post. Available at: http://www.41post.com/?p=4619

import android.app.Activity;
import android.app.ProgressDialog;
import android.os.Bundle;
import android.os.Handler;

public class LoadingScreenActivity extends Activity implements Runnable
{
	//A ProgressDialog View
	private ProgressDialog progressDialog;
	//A thread, that will be used to execute code in parallel with the UI thread
	private Thread thread;
	//Create a Thread handler to queue code execution on a thread
	private Handler handler;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) 
    {
        super.onCreate(savedInstanceState);
        
		//Create a new progress dialog.
		progressDialog = new ProgressDialog(LoadingScreenActivity.this);
		//Set the progress dialog to display a horizontal bar .
		progressDialog.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
		//Set the dialog title to 'Loading...'.
		progressDialog.setTitle("Loading...");
		//Set the dialog message to 'Loading application View, please wait...'.
		progressDialog.setMessage("Loading application View, please wait...");
		//This dialog can't be canceled by pressing the back key.
		progressDialog.setCancelable(false);
		//This dialog isn't indeterminate.
		progressDialog.setIndeterminate(false);
		//The maximum number of progress items is 100.
		progressDialog.setMax(100);
		//Set the current progress to zero.
		progressDialog.setProgress(0);
		//Display the progress dialog.
		progressDialog.show();
		
		//Initialize the handler
        handler = new Handler();
        //Initialize the thread
        thread = new Thread(this, "ProgressDialogThread");
        //start the thread
        thread.start();
    }

	//Initialize a counter integer to zero
	int counter = 0;
    
	@Override
	public void run() 
	{
		try 
		{
			//Obtain the thread's token
			synchronized (thread) 
			{
				//While the counter is smaller than four
				while(counter <= 4)
				{
					//Wait 850 milliseconds
					thread.wait(850);
					//Increment the counter 
					counter++;
					
					//update the changes to the UI thread
					handler.post(new Runnable() 
					{
						@Override
						public void run() 
						{
							//Set the current progress. 
							progressDialog.setProgress(counter*25);
						}
					});
				}
			}
		} 
		catch (InterruptedException e) 
		{
			e.printStackTrace();
		}
		
		//This works just like the onPostExecute method from the AsyncTask class
		handler.post(new Runnable() 
		{
			@Override
			public void run() 
			{
				//Close the progress dialog
				progressDialog.dismiss();
				
				//Call the application's main View
				setContentView(R.layout.main);	
			}
		});
		
		//Try to "kill" the thread, by interrupting its execution
		synchronized (thread) 
		{
			thread.interrupt();
		}
	}
}